==> ntoken-solana-models-0.1.2.crate: ntoken-solana-models-0.1.2/src/constants/instructions_number.rs <==
//! Number of all instructions 

pub const INSTRUCTION_CREATE_ADMIN_ACCOUNT:u8=1;
pub const INSTRUCTION_ADD_ADMIN_ACCOUNT:u8=2;
pub const INSTRUCTION_DELETE_ADMIN_ACCOUNT:u8=3;
pub const INSTRUCTION_UNSTAKE_NFT:u8=4;
pub const INSTRUCTION_STAKE_NFT:u8=5;
pub const INSTRUCTION_CREATE_AIRDROP_ACCOUNT:u8=6;
pub const INSTRUCTION_ADD_PPU_TO_AIRDROP_ACCOUNT:u8=7;
pub const INSTRUCTION_SERUM_SWAP:u8=8;
pub const INSTRUCTION_CLOSE_PPU:u8=9;
pub const INSTRUCTION_UPDATE_STATE_PPU:u8=10;
pub const INSTRUCTION_UPDATE_AMOUNT_PPU:u8=11;
pub const INSTRUCTION_STAKE_LP_TOKEN:u8=12;
pub const INSTRUCTION_UPDATE_SPLU_PPU_STABEL_COINS:u8=13;
pub const INSTRUCTION_DEPOSIT_SERUM:u8=14;
pub const INSTRUCTION_WITHDRAW_SERUM:u8=15;
pub const INSTRUCTION_AIRDROP_TOKENS:u8=16;
pub const INSTRUCTION_UPDATE_STATE_TEERTIARY:u8=17;
pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
pub const INSTRUCTION_RESET_SPLU_PPU:u8=24;
pub const INSTRUCTION_CREATE_INIT_NFT_ACCOUNT:u8=25;
pub const INSTRUCTION_DEPOSIT_INTO_LP:u8=26;
pub const INSTRUCTION_WITHDRAW_FROM_QUARRY:u8=27;
pub const INSTRUCTION_WITHDRAW_FROM_SABER:u8=28;
pub const INSTRUCTION_SWAP_REVERTE:u8=29;
pub const INSTRUCTION_CEARTE_MINER:u8=30;
pub const INSTRUCTION_TRANSFER_WITH_CROSS:u8=31;
pub const INSTRUCTION_UPDATE_SPLU_PPU:u8=32;
pub const INSTRUCTION_UPDATE_SPLU_TERTIARY_PPU:u8=33;
pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
pub const INSTRUCTION_CLAIM_REWARDS:u8=35;
pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
pub const INSTRUCTION_INVEST_MORE:u8=37;
pub const INSTRUCTION_MINT_MORE_N_ASSET:u8=38;
pub const EXTERNAL_INSTRUCTION_WITHDRAW_SABER: u8 = 3;
pub const WITHDRAW_INSTRUCTION_SABER: u8 = 3;
pub const EXTERNAL_INSTRUCTION_APPROVE_SPL: u8 = 4;
pub const EXTERNAL_INSTRUCTION_DEPOSIT_ABER: u8 = 2;
pub const EXTERNAL_INSTRUCTION_TRANSFER_SPL: u8 = 3;

==> ntoken-solana-models-0.2.1.crate: ntoken-solana-models-0.2.1/src/constants/instructions_number.rs <==
//! Number of all instructions 

pub const INSTRUCTION_CREATE_ADMIN_ACCOUNT:u8=1;
pub const INSTRUCTION_ADD_ADMIN_ACCOUNT:u8=2;
pub const INSTRUCTION_DELETE_ADMIN_ACCOUNT:u8=3;
pub const INSTRUCTION_UNSTAKE_NFT:u8=4;
pub const INSTRUCTION_STAKE_NFT:u8=5;
pub const INSTRUCTION_CREATE_AIRDROP_ACCOUNT:u8=6;
pub const INSTRUCTION_ADD_USER_TO_AIRDROP_ACCOUNT:u8=7;
pub const INSTRUCTION_SERUM_SWAP:u8=8;
pub const INSTRUCTION_CLOSE_TURING:u8=9;
pub const INSTRUCTION_CLOSE_TURING_TRIGGUER:u8=9;
pub const INSTRUCTION_UPDATE_STATE_PPU:u8=10;
pub const INSTRUCTION_UPDATE_AMOUNT_PPU:u8=11;
pub const INSTRUCTION_STAKE_LP_TOKEN:u8=12;
pub const INSTRUCTION_UPDATE_SPLU_PPU_STABEL_COINS:u8=13;
pub const INSTRUCTION_DEPOSIT_SERUM:u8=14;
pub const INSTRUCTION_WITHDRAW_SERUM:u8=15;
pub const INSTRUCTION_AIRDROP_TOKENS:u8=16;
pub const INSTRUCTION_UPDATE_STATE_TEERTIARY:u8=17;
pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
pub const INSTRUCTION_RESET_SPLU_PPU:u8=24;
pub const INSTRUCTION_CREATE_INIT_NFT_ACCOUNT:u8=25;
pub const INSTRUCTION_DEPOSIT_INTO_LP:u8=26;
pub const INSTRUCTION_WITHDRAW_FROM_QUARRY:u8=27;
pub const INSTRUCTION_WITHDRAW_FROM_SABER:u8=28;
pub const INSTRUCTION_SWAP_REVERTE:u8=29;
pub const INSTRUCTION_CEARTE_MINER:u8=30;
pub const INSTRUCTION_TRANSFER_WITH_CROSS:u8=31;
pub const INSTRUCTION_UPDATE_SPLU_PPU:u8=32;
pub const INSTRUCTION_UPDATE_SPLU_TERTIARY_PPU:u8=33;
pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
pub const INSTRUCTION_CLAIM_REWARDS:u8=35;
pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
pub const INSTRUCTION_INVEST_MORE:u8=37;
pub const INSTRUCTION_MINT_MORE_N_ASSET:u8=38;
pub const EXTERNAL_INSTRUCTION_WITHDRAW_SABER: u8 = 3;
pub const WITHDRAW_INSTRUCTION_SABER: u8 = 3;
pub const EXTERNAL_INSTRUCTION_APPROVE_SPL: u8 = 4;
pub const EXTERNAL_INSTRUCTION_DEPOSIT_ABER: u8 = 2;
pub const EXTERNAL_INSTRUCTION_TRANSFER_SPL: u8 = 3;
